@@ -4,6 +4,7 @@ namespace DeepCopyTest;
 
 use ArrayObject;
 use DateInterval;
+use DatePeriod;
 use DateTime;
 use DateTimeImmutable;
 use DateTimeZone;
@@ -21,6 +22,7 @@ use DeepCopy\f009;
 use DeepCopy\f011;
 use DeepCopy\f012\Suit;
 use DeepCopy\f013;
+use DeepCopy\f014;
 use DeepCopy\Filter\ChainableFilter;
 use DeepCopy\Filter\Doctrine\DoctrineProxyFilter;
 use DeepCopy\Filter\KeepFilter;
@@ -157,6 +159,7 @@ class DeepCopyTest extends TestCase
         $object->d2 = new DateTimeImmutable();
         $object->dtz = new DateTimeZone('UTC');
         $object->di = new DateInterval('P2D');
+        $object->dp = new DatePeriod(new DateTime(), new DateInterval('P2D'), 3);
 
         $copy = deep_copy($object);
 
@@ -164,6 +167,7 @@ class DeepCopyTest extends TestCase
         $this->assertEqualButNotSame($object->d2, $copy->d2);
         $this->assertEqualButNotSame($object->dtz, $copy->dtz);
         $this->assertEqualButNotSame($object->di, $copy->di);
+        $this->assertEqualButNotSame($object->dp, $copy->dp);
     }
 
     /**
@@ -542,6 +546,23 @@ class DeepCopyTest extends TestCase
         $this->assertNotEquals($copy->getFoo(), $object->getFoo());
     }
 
+    /**
+     * @requires PHP 8.1
+     */
+    public function test_it_can_copy_object_with_readonly_property()
+    {
+        $scalarProperties = new f014\ReadonlyScalarProperty();
+        $objectProperties = new f014\ReadonlyObjectProperty();
+
+        $deepCopy = new DeepCopy();
+
+        $scalarPropertiesCopy = $deepCopy->copy($scalarProperties);
+        $objectPropertiesCopy = $deepCopy->copy($objectProperties);
+
+        $this->assertEqualButNotSame($scalarProperties, $scalarPropertiesCopy);
+        $this->assertEqualButNotSame($objectProperties, $objectPropertiesCopy);
+    }
+
     private function assertEqualButNotSame($expected, $val)
     {
         $this->assertEquals($expected, $val);
